require_relative 'api'
require_relative 'project'

module Gitlab
  module Cli
    class GitLab
      def initialize(options)
        @api = Gitlab::Cli::Api.new(options)
      end

      def projects(group_id = nil)
        projects_json = @api.http_get(group_id ? "groups/#{group_id}/projects" : 'projects')
        projects = []
        projects_json.each do |proj_json|
          projects << Gitlab::Cli::Project.new(@api, id: proj_json['id'], name: proj_json['name'])
        end
        projects
      end

      def apply_group_settings(group_settings)
        group_settings.each do |group_name, setting|
          p "Applying settings to: #{group_name}"
          group_id = group_id(group_name)
          all_projects = projects(group_id)
          all_projects.each do |project|
            setting.each do |name, value|
              project.send('update_'+name, value)
            end
          end
        end
      end

      private

      def group_id(group_name)
        grp = @api.http_get('groups').find {|g| g['name'] == group_name}
        grp ? grp['id'] : raise("Group #{group_name} not found")
      end

    end
  end
end
