require_relative 'api'

module Gitlab
  module Cli
    class Project
      attr_accessor :id, :name

      def initialize(api, options)
        @id = options[:id]
        @name = options[:name]
        @api = api
      end

      def update_variables(variables)
        if @id == 534
          delete_existing_vars
          create_given_vars(variables)
        end
      end

      private

      def create_given_vars(variables)
        variables.each do |variable|
          res = create_variable variable
          p res
        end
      end

      def delete_existing_vars
        response = @api.http_get("projects/#{@id}/variables")
        response.each {|var| delete_variable(var['key'])}
      end

      def create_variable(variable)
        p "Creating variable #{variable}"

        response = @api.http_post("projects/#{@id}/variables", variable.to_json)

        response_body = JSON.parse(response.body)
        p "JSON Response: #{response_body}"

        if response.code == 201
          p "Created variable #{variable}"
          response_body
        elsif response_body['message'] && response_body['message'] == '401 Unauthorized'
          raise response_body.inspect
        elsif response_body['message'] && response_body['message']['key'].include?('has already been taken')
          raise "#{variable['key']} is already used"
        else
          response
        end
      end

      def delete_variable(key)
        p "deleting #{key}"
        response = @api.http_delete("/projects/#{@id}/variables/#{key}")
        if response.body
          json_response = JSON.parse(response.body)
          p "DELETE JSON Response : #{json_response}"
          json_response
        end

      end

    end
  end
end
